@@ -169,8 +169,12 @@
 /* target attribute */
 #if defined(__GNUC__) || __has_attribute(target)
 #define ATTR_TARGET(x) __attribute__((target((x))))
+#define ATTR_TARGET_AVX2 __attribute__((target("avx2,bmi2")))
+#define ATTR_TARGET_SSE2 __attribute__((target("sse")))
 #else
 #define ATTR_TARGET(x)
+#define ATTR_TARGET_AVX2
+#define ATTR_TARGET_SSE2
 #endif
 
 /* artificial attribute */
@@ -180,9 +184,6 @@
 #define ATTR_ARTIFICIAL
 #endif
 
-#define ATTR_TARGET_AVX2 ATTR_TARGET("avx2,bmi2")
-#define ATTR_TARGET_SSE2 ATTR_TARGET("sse2")
-
 #define FN_ATTRIBUTES_AVX2 ATTR_ARTIFICIAL ATTR_ALWAYS_INLINE ATTR_TARGET_AVX2
 #define FN_ATTRIBUTES_SSE2 ATTR_ARTIFICIAL ATTR_ALWAYS_INLINE ATTR_TARGET_SSE2
 #define FN_ATTRIBUTES_NEON ATTR_ARTIFICIAL ATTR_ALWAYS_INLINE
@@ -217,30 +218,11 @@ static inline bool sub_overflow_size_t(const size_t x, const size_t y, size_t* d
 
 /* helper functions for parity computations */
 #if GNUC_CHECK(4, 9) || __has_builtin(__builtin_parity)
-ATTR_CONST ATTR_ARTIFICIAL static inline uint8_t parity64_uint8(uint8_t in) {
-  return __builtin_parity(in);
-}
-
-ATTR_CONST ATTR_ARTIFICIAL static inline uint16_t parity64_uint16(uint16_t in) {
-  return __builtin_parity(in);
-}
-
 ATTR_CONST ATTR_ARTIFICIAL static inline uint64_t parity64_uint64(uint64_t in) {
   return __builtin_parityll(in);
 }
 #else
-ATTR_CONST ATTR_ARTIFICIAL static inline uint8_t parity64_uint8(uint8_t in) {
-  /* byte parity from: https://graphics.stanford.edu/~seander/bithacks.html#ParityWith64Bits */
-  return (((in * UINT64_C(0x0101010101010101)) & UINT64_C(0x8040201008040201)) % 0x1FF) & 1;
-}
-
-ATTR_CONST ATTR_ARTIFICIAL static inline uint16_t parity64_uint16(uint16_t in) {
-  in ^= in >> 1;
-  in ^= in >> 2;
-  in = (in & 0x1111) * 0x1111;
-  return (in >> 12) & 1;
-}
-
+/* byte parity from: https://graphics.stanford.edu/~seander/bithacks.html#ParityWith64Bits */
 ATTR_CONST ATTR_ARTIFICIAL static inline uint64_t parity64_uint64(uint64_t in) {
   in ^= in >> 1;
   in ^= in >> 2;
